garbage_collector — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- model_thread »

# garbage_collector

class `camelot.view.model_thread.garbage_collector.` `GarbageCollector`(parent, debug=False)

  Disable automatic garbage collection and instead collect manually every INTERVAL milliseconds.

  This is done to ensure that garbage collection only happens in the GUI thread, as otherwise Qt can crash.

  This code is serves as a workaround for a bug in PyQt:

  and is modeled after the original code of Kovid Goyal

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- model_thread »

Comments
blog comments powered by Disqus